@@ -11,4 +11,4 @@ logger = logging.getLogger(__name__)
 
 
 if __name__ == "__main__":
-    fire.Fire(LogQS())
+    fire.Fire(LogQS)
