@@ -56,6 +56,8 @@ class RESTInterface:
         url_params = ""
         for key, value in args.items():
             if value is not None and key not in ["self"] + exclude:
+                if type(value) == dict or type(value) == list:
+                    value = json.dumps(value)
                 url_params += f"&{key}={value}"
         if len(url_params) > 0:
             url_params = "?" + url_params[1:]
